@@ -9,7 +9,7 @@ use crate::{
     irust::format::{format_check_output, format_err, format_eval_output},
     utils::ctrlc_cancel,
 };
-use irust_repl::{cargo_cmds::*, EvalResult, Executor, ToolChain};
+use irust_repl::{cargo_cmds::*, EvalConfig, EvalResult, Executor, ToolChain};
 use printer::printer::{PrintQueue, PrinterItem};
 
 const SUCCESS: &str = "Ok!";
@@ -66,6 +66,7 @@ impl IRust {
             cmd if cmd.starts_with(":bench") => self.bench(),
             cmd if cmd.starts_with(":asm") => self.asm(),
             cmd if cmd.starts_with(":executor") => self.executor(),
+            cmd if cmd.starts_with(":evaluator") => self.evaluator(),
             cmd if cmd.starts_with(":scripts") => self.scripts(),
             _ => self.parse_second_order(),
         }
@@ -378,9 +379,12 @@ impl IRust {
             let mut outputs = PrintQueue::default();
 
             self.while_compiling_hook();
-            let result = self
-                .repl
-                .eval_with_configuration(buffer, ctrlc_cancel, true);
+            let result = self.repl.eval_with_configuration(EvalConfig {
+                input: buffer,
+                interactive_function: Some(ctrlc_cancel),
+                color: true,
+                evaluator: &self.options.evaluator,
+            });
             self.after_compiling_hook();
             let EvalResult { output, status } = result?;
 
@@ -561,6 +565,40 @@ impl IRust {
             print_queue!(self.options.executor.to_string(), Color::Blue)
         }
     }
+
+    fn evaluator(&mut self) -> Result<PrintQueue> {
+        let buffer = self.buffer.to_string();
+        let evaluator = buffer
+            .strip_prefix(":evaluator")
+            .expect("already checked")
+            .trim();
+        // get
+        if evaluator.is_empty() {
+            return print_queue!(self.options.evaluator.join("$$"), Color::Blue);
+        }
+
+        // reset
+        if evaluator == "reset" {
+            self.options.reset_evaluator();
+            return success!();
+        }
+
+        // set
+        if !evaluator.contains("$$") {
+            return Err(
+                "evaluator must contain `$$`, `$$` will be replaced by IRust by the code input"
+                    .into(),
+            );
+        }
+        let evaluator: Vec<String> = evaluator.split("$$").map(ToOwned::to_owned).collect();
+        if evaluator.len() != 2 {
+            return Err("evaluator requires two parts".into());
+        }
+
+        self.options.evaluator = evaluator;
+        success!()
+    }
+
     fn scripts(&mut self) -> Result<PrintQueue> {
         if let Some(scripts_list) = self.scripts_list() {
             print_queue!(scripts_list, Color::Cyan)
